.. Copyright 2021, 2022 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.plotly
------------------------------

.. sidebar:: Behind the scenes

   This module uses `plotly.js <https://github.com/plotly/plotly.js/>`_ to
   render figures you create in Python using `plotly.py <https://github.com/plotly/plotly.py/>`_.

.. automodule:: reahl.web.plotly



Chart
"""""

.. sidebar:: Examples in this section

   - howtos.chartplotly
   - howtos.chartplotly2

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. autoclass:: Chart
   :members:

